Page MenuHomeDevCentral

D769.diff
No OneTemporary

D769.diff

diff --git a/app/Actions/Action.php b/app/Actions/Action.php
--- a/app/Actions/Action.php
+++ b/app/Actions/Action.php
@@ -9,7 +9,7 @@
public $action;
/**
- * @var Nasqueron\Notifications\Actions\ActionError
+ * @var ActionError
*/
public $error;
@@ -28,7 +28,7 @@
* $actionToReport->attachError(new ActionError($exception));
* </code>
*
- * @param Nasqueron\Notifications\Actions\ActionError $error The error to attach
+ * @param ActionError $error The error to attach
*/
public function attachError (ActionError $error) {
$this->error = $error;
diff --git a/app/Analyzers/BasePayloadAnalyzer.php b/app/Analyzers/BasePayloadAnalyzer.php
--- a/app/Analyzers/BasePayloadAnalyzer.php
+++ b/app/Analyzers/BasePayloadAnalyzer.php
@@ -22,13 +22,13 @@
/**
* The request content, as a structured data
- * @var stdClass
+ * @var \stdClass
*/
protected $payload;
/**
* The configuration for the payload analyzer
- * @var Nasqueron\Notifications\Analyzers\BasePayloadAnalyzerConfiguration;
+ * @var BasePayloadAnalyzerConfiguration;
*/
protected $configuration;
@@ -40,7 +40,7 @@
* Creates a new JenkinsPayloadAnalyzer instance.
*
* @param string $project
- * @param stdClass $payload
+ * @param \stdClass $payload
*/
public function __construct($project, $payload) {
if (!is_object($payload)) {
diff --git a/app/Analyzers/DockerHub/BaseEvent.php b/app/Analyzers/DockerHub/BaseEvent.php
--- a/app/Analyzers/DockerHub/BaseEvent.php
+++ b/app/Analyzers/DockerHub/BaseEvent.php
@@ -5,14 +5,14 @@
abstract class BaseEvent {
/**
- * @var stdClass
+ * @var \stdClass
*/
protected $payload;
/**
* Initializes a new instance of the BaseEvent object.
*
- * @param stdClass $payload The payload to analyze
+ * @param \stdClass $payload The payload to analyze
*/
public function __construct ($payload) {
$this->payload = $payload;
diff --git a/app/Analyzers/DockerHub/BuildFailureEvent.php b/app/Analyzers/DockerHub/BuildFailureEvent.php
--- a/app/Analyzers/DockerHub/BuildFailureEvent.php
+++ b/app/Analyzers/DockerHub/BuildFailureEvent.php
@@ -9,7 +9,7 @@
/**
* Initializes a new instance of the BuildFailureEvent object.
*
- * @param stdClass $payload The payload to analyze
+ * @param \stdClass $payload The payload to analyze
*/
public function __construct ($payload) {
parent::__construct($payload);
@@ -19,7 +19,7 @@
/**
* Gets a MailGun message.
*
- * @return stdClass
+ * @return \stdClass
*/
private function getMailGunPayload () {
return Mailgun::fetchMessageFromPayload($this->payload);
diff --git a/app/Analyzers/GitHub/Events/Event.php b/app/Analyzers/GitHub/Events/Event.php
--- a/app/Analyzers/GitHub/Events/Event.php
+++ b/app/Analyzers/GitHub/Events/Event.php
@@ -11,7 +11,7 @@
/**
* The payload
*
- * @var stdClass
+ * @var \stdClass
*/
protected $payload;
diff --git a/app/Analyzers/GitHub/Events/PushEvent.php b/app/Analyzers/GitHub/Events/PushEvent.php
--- a/app/Analyzers/GitHub/Events/PushEvent.php
+++ b/app/Analyzers/GitHub/Events/PushEvent.php
@@ -16,7 +16,7 @@
* Gets the description message key according the amount of commits
*
* @param int $count The count of commits
- * @return The l10n message key for description
+ * @return string The l10n message key for description
*/
private static function getDescriptionMessageKey ($count) {
$key = 'GitHub.EventsDescriptions.PushEvent';
diff --git a/app/Analyzers/GitHub/GitHubPayloadAnalyzer.php b/app/Analyzers/GitHub/GitHubPayloadAnalyzer.php
--- a/app/Analyzers/GitHub/GitHubPayloadAnalyzer.php
+++ b/app/Analyzers/GitHub/GitHubPayloadAnalyzer.php
@@ -26,7 +26,7 @@
/**
* The payload analyzer event
*
- * @var Nasqueron\Notifications\Analyzers\GitHub\Events\Event;
+ * @var \Nasqueron\Notifications\Analyzers\GitHub\Events\Event;
*/
private $analyzerEvent;
@@ -39,7 +39,7 @@
*
* @param string $project
* @param string $event
- * @param stdClass $payload
+ * @param \stdClass $payload
*/
public function __construct($project, $event, $payload) {
parent::__construct($project, $payload);
diff --git a/app/Console/Commands/NotificationsPayload.php b/app/Console/Commands/NotificationsPayload.php
--- a/app/Console/Commands/NotificationsPayload.php
+++ b/app/Console/Commands/NotificationsPayload.php
@@ -169,7 +169,7 @@
* Initializes a new instance of the relevant notification class,
* with the arguments given in the constructor property.
*
- * @return Nasqueron\Notifications\Notification
+ * @return \Nasqueron\Notifications\Notification
*/
private function getNotification () {
$class = $this->getNotificationClass();
diff --git a/app/Contracts/APIFactory.php b/app/Contracts/APIFactory.php
--- a/app/Contracts/APIFactory.php
+++ b/app/Contracts/APIFactory.php
@@ -8,7 +8,7 @@
* Gets an instance of the API client class
*
* @param string $endPoint The API end point
- * @return Nasqueron\Notifications\Contracts\APIClient
+ * @return APIClient
*/
public function get ($endPoint);
diff --git a/app/Events/DockerHubPayloadEvent.php b/app/Events/DockerHubPayloadEvent.php
--- a/app/Events/DockerHubPayloadEvent.php
+++ b/app/Events/DockerHubPayloadEvent.php
@@ -22,7 +22,7 @@
/**
* The request content, as a structured data
- * @var stdClass
+ * @var \stdClass
*/
public $payload;
@@ -43,7 +43,7 @@
* Creates a new event instance.
*
* @param string $door
- * @param stdClass $payload
+ * @param \stdClass $payload
*/
public function __construct($door, $payload) {
$this->door = $door;
diff --git a/app/Events/GitHubPayloadEvent.php b/app/Events/GitHubPayloadEvent.php
--- a/app/Events/GitHubPayloadEvent.php
+++ b/app/Events/GitHubPayloadEvent.php
@@ -22,7 +22,7 @@
/**
* The request content, as a structured data
- * @var stdClass
+ * @var \stdClass
*/
public $payload;
@@ -31,7 +31,7 @@
*
* @param string $door
* @param string $event
- * @param stdClass $payload
+ * @param \stdClass $payload
*/
public function __construct($door, $event, $payload) {
$this->door = $door;
diff --git a/app/Events/JenkinsPayloadEvent.php b/app/Events/JenkinsPayloadEvent.php
--- a/app/Events/JenkinsPayloadEvent.php
+++ b/app/Events/JenkinsPayloadEvent.php
@@ -16,7 +16,7 @@
/**
* The request content, as a structured data
- * @var stdClass
+ * @var \stdClass
*/
public $payload;
@@ -24,7 +24,7 @@
* Creates a new event instance.
*
* @param string $door
- * @param stdClass $payload
+ * @param \stdClass $payload
*/
public function __construct($door, $payload) {
$this->door = $door;
diff --git a/app/Events/PhabricatorPayloadEvent.php b/app/Events/PhabricatorPayloadEvent.php
--- a/app/Events/PhabricatorPayloadEvent.php
+++ b/app/Events/PhabricatorPayloadEvent.php
@@ -17,6 +17,7 @@
/**
* The raw payload
+ * @var iterable
*/
public $payload;
@@ -32,7 +33,7 @@
* @return PhabricatorStory
*/
protected function getStory () {
- return PhabricatorStory::loadFromArray(
+ return PhabricatorStory::loadFromIterable(
$this->door,
$this->payload
);
@@ -42,9 +43,9 @@
* Creates a new event instance.
*
* @param string $door
- * @param stdClass $payload
+ * @param iterable $payload
*/
- public function __construct($door, $payload) {
+ public function __construct(string $door, iterable $payload) {
$this->door = $door;
$this->payload = $payload;
diff --git a/app/Http/Controllers/Gate/DockerHubGateController.php b/app/Http/Controllers/Gate/DockerHubGateController.php
--- a/app/Http/Controllers/Gate/DockerHubGateController.php
+++ b/app/Http/Controllers/Gate/DockerHubGateController.php
@@ -16,7 +16,7 @@
/**
* The request content, as a structured data
*
- * @var stdClass
+ * @var \stdClass
*/
private $payload;
@@ -44,7 +44,7 @@
* Handles POST requests
*
* @param Request $request the HTTP request
- * @return Illuminate\Http\Response
+ * @return \Illuminate\Http\Response
*/
public function onPost ($door) {
// Parses the request and check if it's legit
diff --git a/app/Http/Controllers/Gate/GateController.php b/app/Http/Controllers/Gate/GateController.php
--- a/app/Http/Controllers/Gate/GateController.php
+++ b/app/Http/Controllers/Gate/GateController.php
@@ -65,7 +65,7 @@
/**
* Renders the report
*
- * @return Illuminate\Http\Response|null
+ * @return \Illuminate\Http\Response|null
*/
protected function renderReport () {
if (Features::isEnabled('ActionsReport')) {
@@ -83,7 +83,7 @@
/**
* Gets service credentials for this gate and door
*
- * @return stdClass the service credentials
+ * @return \stdClass the service credentials
*/
public function getService () {
return Services::findServiceByDoor(static::SERVICE_NAME, $this->door);
diff --git a/app/Http/Controllers/Gate/GitHubGateController.php b/app/Http/Controllers/Gate/GitHubGateController.php
--- a/app/Http/Controllers/Gate/GitHubGateController.php
+++ b/app/Http/Controllers/Gate/GitHubGateController.php
@@ -38,7 +38,7 @@
/**
* The request content, as a structured data
*
- * @var stdClass
+ * @var \stdClass
*/
private $payload;
@@ -66,7 +66,7 @@
* Handles POST requests
*
* @param Request $request the HTTP request
- * @return Illuminate\Http\Response
+ * @return \Illuminate\Http\Response
*/
public function onPost ($door) {
// Parses the request and check if it's legit
diff --git a/app/Http/Controllers/Gate/JenkinsGateController.php b/app/Http/Controllers/Gate/JenkinsGateController.php
--- a/app/Http/Controllers/Gate/JenkinsGateController.php
+++ b/app/Http/Controllers/Gate/JenkinsGateController.php
@@ -16,7 +16,7 @@
/**
* The request content, as a structured data
*
- * @var stdClass
+ * @var \stdClass
*/
private $payload;
@@ -44,7 +44,7 @@
* Handles POST requests
*
* @param Request $request the HTTP request
- * @return Illuminate\Http\Response
+ * @return \Illuminate\Http\Response
*/
public function onPost ($door) {
// Parses the request and check if it's legit
diff --git a/app/Http/Controllers/Gate/PhabricatorGateController.php b/app/Http/Controllers/Gate/PhabricatorGateController.php
--- a/app/Http/Controllers/Gate/PhabricatorGateController.php
+++ b/app/Http/Controllers/Gate/PhabricatorGateController.php
@@ -16,7 +16,7 @@
/**
* The request content, as a structured data
*
- * @var string
+ * @var array
*/
private $payload;
diff --git a/app/Jobs/FireDockerHubNotification.php b/app/Jobs/FireDockerHubNotification.php
--- a/app/Jobs/FireDockerHubNotification.php
+++ b/app/Jobs/FireDockerHubNotification.php
@@ -43,7 +43,7 @@
* Creates a DockerHub notification
*
* @param DockerHubPayloadEvent $event
- * @return Notification the notification
+ * @return \Nasqueron\Notifications\Notification The notification
*/
protected function createNotification() {
return new DockerHubNotification(
diff --git a/app/Jobs/FireGitHubNotification.php b/app/Jobs/FireGitHubNotification.php
--- a/app/Jobs/FireGitHubNotification.php
+++ b/app/Jobs/FireGitHubNotification.php
@@ -43,7 +43,7 @@
* Creates a GitHub notification
*
* @param GitHubPayloadEvent $event
- * @return Notification the notification
+ * @return \Nasqueron\Notifications\Notification The notification
*/
protected function createNotification() {
return new GitHubNotification(
diff --git a/app/Jobs/FireJenkinsNotification.php b/app/Jobs/FireJenkinsNotification.php
--- a/app/Jobs/FireJenkinsNotification.php
+++ b/app/Jobs/FireJenkinsNotification.php
@@ -45,7 +45,7 @@
* Creates a Jenkins notification
*
* @param JenkinsPayloadEvent $event
- * @return Notification the notification
+ * @return \Nasqueron\Notifications\Notification The notification
*/
protected function createNotification() {
return new JenkinsNotification(
diff --git a/app/Jobs/FirePhabricatorNotification.php b/app/Jobs/FirePhabricatorNotification.php
--- a/app/Jobs/FirePhabricatorNotification.php
+++ b/app/Jobs/FirePhabricatorNotification.php
@@ -43,7 +43,7 @@
* Creates a Phabricator notification
*
* @param PhabricatorPayloadEvent $event
- * @return Notification the notification
+ * @return \Nasqueron\Notifications\Notification The notification
*/
protected function createNotification() {
return new PhabricatorNotification(
diff --git a/app/Listeners/AMQPEventListener.php b/app/Listeners/AMQPEventListener.php
--- a/app/Listeners/AMQPEventListener.php
+++ b/app/Listeners/AMQPEventListener.php
@@ -124,7 +124,7 @@
/**
* Register the listeners for the subscriber.
*
- * @param Illuminate\Events\Dispatcher $events
+ * @param \Illuminate\Events\Dispatcher $events
*/
public function subscribe (\Illuminate\Events\Dispatcher $events) {
$class = 'Nasqueron\Notifications\Listeners\AMQPEventListener';
diff --git a/app/Listeners/LastPayloadSaver.php b/app/Listeners/LastPayloadSaver.php
--- a/app/Listeners/LastPayloadSaver.php
+++ b/app/Listeners/LastPayloadSaver.php
@@ -34,7 +34,7 @@
/**
* Register the listeners for the subscriber.
*
- * @param Illuminate\Events\Dispatcher $events
+ * @param \Illuminate\Events\Dispatcher $events
*/
public function subscribe (\Illuminate\Events\Dispatcher $events) {
$ns = 'Nasqueron\Notifications\Events';
diff --git a/app/Listeners/NotificationListener.php b/app/Listeners/NotificationListener.php
--- a/app/Listeners/NotificationListener.php
+++ b/app/Listeners/NotificationListener.php
@@ -68,7 +68,7 @@
/**
* Register the listeners for the subscriber.
*
- * @param Illuminate\Events\Dispatcher $events
+ * @param \Illuminate\Events\Dispatcher $events
*/
public function subscribe (\Illuminate\Events\Dispatcher $events) {
$class = 'Nasqueron\Notifications\Listeners\NotificationListener';
diff --git a/app/Notifications/PhabricatorNotification.php b/app/Notifications/PhabricatorNotification.php
--- a/app/Notifications/PhabricatorNotification.php
+++ b/app/Notifications/PhabricatorNotification.php
@@ -35,7 +35,7 @@
/**
* Gets analyzer
*
- * @return Nasqueron\Notifications\Analyzers\Phabricator\PhabricatorPayloadAnalyzer
+ * @return \Nasqueron\Notifications\Analyzers\Phabricator\PhabricatorPayloadAnalyzer
*/
private function getAnalyzer () {
if ($this->analyzer === null) {
diff --git a/app/Phabricator/PhabricatorAPIFactory.php b/app/Phabricator/PhabricatorAPIFactory.php
--- a/app/Phabricator/PhabricatorAPIFactory.php
+++ b/app/Phabricator/PhabricatorAPIFactory.php
@@ -10,7 +10,7 @@
* Gets an instance of the Phabricator API client class.
*
* @param string $instance The Phabricator instance
- * @return Nasqueron\Notifications\Phabricator\PhabricatorAPI
+ * @return \Nasqueron\Notifications\Phabricator\PhabricatorAPI
*/
public function get ($instance) {
return PhabricatorAPI::forInstance($instance);
@@ -20,7 +20,7 @@
* Gets an instance of the Phabricator API client class for a project.
*
* @param string $project The Phabricator project name
- * @return Nasqueron\Notifications\Phabricator\PhabricatorAPI
+ * @return PhabricatorAPI
*/
public function getForProject ($project) {
return PhabricatorAPI::forProject($project);
diff --git a/app/Phabricator/ProjectsMap.php b/app/Phabricator/ProjectsMap.php
--- a/app/Phabricator/ProjectsMap.php
+++ b/app/Phabricator/ProjectsMap.php
@@ -34,7 +34,7 @@
/**
*
- * @var Nasqueron\Notifications\Contracts\APIClient
+ * @var \Nasqueron\Notifications\Contracts\APIClient
*/
private $apiClient;
@@ -140,7 +140,7 @@
* Gets a new ProjectsMap instance and queries Phabricator API to fill it.
*
* @param string $phabricatorInstanceName The Phabricator instance name
- * @param Nasqueron\Notifications\Contracts\APIClient $apiClient The Phabricator API client
+ * @param \Nasqueron\Notifications\Contracts\APIClient $apiClient The Phabricator API client
* @return ProjectsMap
*/
public static function fetch ($phabricatorInstanceName, ?APIClient $apiClient = null) {
@@ -155,7 +155,7 @@
///
/**
- * @return Nasqueron\Notifications\Contracts\APIClient
+ * @return \Nasqueron\Notifications\Contracts\APIClient
*/
public function getAPIClient () {
if ($this->apiClient === null) {
@@ -166,7 +166,7 @@
}
/**
- * @param Nasqueron\Notifications\Contracts\APIClient $apiClient
+ * @param \Nasqueron\Notifications\Contracts\APIClient|null $apiClient
*/
public function setAPIClient (?APIClient $apiClient = null) {
$this->apiClient = $apiClient;
diff --git a/app/Phabricator/ProjectsMapFactory.php b/app/Phabricator/ProjectsMapFactory.php
--- a/app/Phabricator/ProjectsMapFactory.php
+++ b/app/Phabricator/ProjectsMapFactory.php
@@ -8,7 +8,7 @@
* Loads projects map from cache or fetches it from API if not cached.
*
* @param string $instanceName The Phabricator instance name
- * @return Nasqueron\Notifications\Phabricator\ProjectsMap
+ * @return ProjectsMap
*/
public function load ($instanceName) {
return ProjectsMap::load($instanceName);
@@ -18,7 +18,7 @@
* Fetches projects map from API.
*
* @param string $instanceName The Phabricator instance name
- * @return Nasqueron\Notifications\Phabricator\ProjectsMap
+ * @return ProjectsMap
*/
public function fetch ($instanceName) {
return ProjectsMap::fetch($instanceName);
diff --git a/app/Providers/ReportServiceProvider.php b/app/Providers/ReportServiceProvider.php
--- a/app/Providers/ReportServiceProvider.php
+++ b/app/Providers/ReportServiceProvider.php
@@ -26,8 +26,8 @@
/**
* Listen to actions fired by the application to add to the report
*
- * @param Nasqueron\Notifications\Actions\ActionsReport $report The report to add actions to
- * @param Illuminate\Contracts\Events\Dispatcher $events The application events dispatcher
+ * @param \Nasqueron\Notifications\Actions\ActionsReport $report The report to add actions to
+ * @param \Illuminate\Contracts\Events\Dispatcher $events The application events dispatcher
*/
public static function listenToActionsForReport (ActionsReport $report, Dispatcher $events) {
$events->listen(
diff --git a/app/Services/Services.php b/app/Services/Services.php
--- a/app/Services/Services.php
+++ b/app/Services/Services.php
@@ -72,7 +72,7 @@
*
* @param string $gate The gate (e.g. GitHub)
* @param string $door The door (e.g. Nasqueron)
- * @return stdClass|null The service information is found; otherwise, null.
+ * @return \stdClass|null The service information is found; otherwise, null.
*/
public function findServiceByDoor ($gate, $door) {
foreach ($this->services as $service) {
@@ -90,7 +90,7 @@
* @param string $gate The gate (e.g. Phabricator)
* @param string $property The property to check (e.g. instance)
* @param mixed $value The property value to find (e.g. 'http://devcentral.nasqueron.org')
- * @return stdClass|null The service information is found; otherwise, null.
+ * @return \stdClass|null The service information is found; otherwise, null.
*/
public function findServiceByProperty ($gate, $property, $value) {
foreach ($this->services as $service) {
diff --git a/tests/Analyzers/GitHub/Events/IssueCommentEventTest.php b/tests/Analyzers/GitHub/Events/IssueCommentEventTest.php
--- a/tests/Analyzers/GitHub/Events/IssueCommentEventTest.php
+++ b/tests/Analyzers/GitHub/Events/IssueCommentEventTest.php
@@ -8,7 +8,7 @@
class IssueCommentEventTest extends TestCase {
/**
- * @var stdClass
+ * @var \stdClass
*/
private $payload;
diff --git a/tests/Analyzers/GitHub/Events/PullRequestEventTest.php b/tests/Analyzers/GitHub/Events/PullRequestEventTest.php
--- a/tests/Analyzers/GitHub/Events/PullRequestEventTest.php
+++ b/tests/Analyzers/GitHub/Events/PullRequestEventTest.php
@@ -8,7 +8,7 @@
class PullRequestEventTest extends TestCase {
/**
- * @var stdClass
+ * @var \stdClass
*/
private $payload;
diff --git a/tests/Analyzers/GitHub/Events/PushEventTest.php b/tests/Analyzers/GitHub/Events/PushEventTest.php
--- a/tests/Analyzers/GitHub/Events/PushEventTest.php
+++ b/tests/Analyzers/GitHub/Events/PushEventTest.php
@@ -8,7 +8,7 @@
class PushEventTest extends TestCase {
/**
- * @var stdClass[]
+ * @var \stdClass[]
*/
private $payloads;
diff --git a/tests/Analyzers/GitHub/Events/RepositoryEventTest.php b/tests/Analyzers/GitHub/Events/RepositoryEventTest.php
--- a/tests/Analyzers/GitHub/Events/RepositoryEventTest.php
+++ b/tests/Analyzers/GitHub/Events/RepositoryEventTest.php
@@ -8,7 +8,7 @@
class RepositoryEventTest extends TestCase {
/**
- * @var stdClass
+ * @var \stdClass
*/
private $payload;
diff --git a/tests/Analyzers/GitHub/Events/StatusEventTest.php b/tests/Analyzers/GitHub/Events/StatusEventTest.php
--- a/tests/Analyzers/GitHub/Events/StatusEventTest.php
+++ b/tests/Analyzers/GitHub/Events/StatusEventTest.php
@@ -8,7 +8,7 @@
class StatusEventTest extends TestCase {
/**
- * @var stdClass
+ * @var \stdClass
*/
private $payload;
diff --git a/tests/Analyzers/GitHub/Events/UnknownEventTest.php b/tests/Analyzers/GitHub/Events/UnknownEventTest.php
--- a/tests/Analyzers/GitHub/Events/UnknownEventTest.php
+++ b/tests/Analyzers/GitHub/Events/UnknownEventTest.php
@@ -8,7 +8,7 @@
class UnknownEventTest extends TestCase {
/**
- * @var Nasqueron\Notifications\Analyzers\GitHub\Events\UnknownEvent
+ * @var \Nasqueron\Notifications\Analyzers\GitHub\Events\UnknownEvent
*/
private $event;
diff --git a/tests/Analyzers/GitHub/GitHubPayloadAnalyzerTest.php b/tests/Analyzers/GitHub/GitHubPayloadAnalyzerTest.php
--- a/tests/Analyzers/GitHub/GitHubPayloadAnalyzerTest.php
+++ b/tests/Analyzers/GitHub/GitHubPayloadAnalyzerTest.php
@@ -8,22 +8,22 @@
class GitHubPayloadAnalyzerTest extends TestCase {
/**
- * @var Nasqueron\Notifications\Analyzers\GitHub\GitHubPayloadAnalyzer
+ * @var \Nasqueron\Notifications\Analyzers\GitHub\GitHubPayloadAnalyzer
*/
private $unknownEventAnalyzer;
/**
- * @var Nasqueron\Notifications\Analyzers\GitHub\GitHubPayloadAnalyzer
+ * @var \Nasqueron\Notifications\Analyzers\GitHub\GitHubPayloadAnalyzer
*/
private $pingAnalyzer;
/**
- * @var Nasqueron\Notifications\Analyzers\GitHub\GitHubPayloadAnalyzer
+ * @var \Nasqueron\Notifications\Analyzers\GitHub\GitHubPayloadAnalyzer
*/
private $pushAnalyzer;
/**
- * @var Nasqueron\Notifications\Analyzers\GitHub\GitHubPayloadAnalyzer
+ * @var \Nasqueron\Notifications\Analyzers\GitHub\GitHubPayloadAnalyzer
*/
private $pushToMappedRepositoryAnalyzer;
diff --git a/tests/Analyzers/Jenkins/JenkinsPayloadAnalyzerConfigurationTest.php b/tests/Analyzers/Jenkins/JenkinsPayloadAnalyzerConfigurationTest.php
--- a/tests/Analyzers/Jenkins/JenkinsPayloadAnalyzerConfigurationTest.php
+++ b/tests/Analyzers/Jenkins/JenkinsPayloadAnalyzerConfigurationTest.php
@@ -13,7 +13,7 @@
/**
* Configuration
*
- * @var Nasqueron\Notifications\Analyzers\Jenkins\JenkinsPayloadAnalyzerConfiguration
+ * @var \Nasqueron\Notifications\Analyzers\Jenkins\JenkinsPayloadAnalyzerConfiguration
*/
protected $configuration;
diff --git a/tests/Analyzers/Jenkins/JenkinsPayloadAnalyzerTest.php b/tests/Analyzers/Jenkins/JenkinsPayloadAnalyzerTest.php
--- a/tests/Analyzers/Jenkins/JenkinsPayloadAnalyzerTest.php
+++ b/tests/Analyzers/Jenkins/JenkinsPayloadAnalyzerTest.php
@@ -11,12 +11,12 @@
/**
* Jenkins analyzer to a successful build
*
- * @var Nasqueron\Notifications\Analyzers\Jenkins\JenkinsPayloadAnalyzer
+ * @var \Nasqueron\Notifications\Analyzers\Jenkins\JenkinsPayloadAnalyzer
*/
protected $analyzer;
/**
- * @var stdClass
+ * @var \stdClass
*/
protected $payload;
diff --git a/tests/Analyzers/PayloadAnalyzerConfigurationTest.php b/tests/Analyzers/PayloadAnalyzerConfigurationTest.php
--- a/tests/Analyzers/PayloadAnalyzerConfigurationTest.php
+++ b/tests/Analyzers/PayloadAnalyzerConfigurationTest.php
@@ -13,7 +13,7 @@
/**
* Configuration
*
- * @var Nasqueron\Notifications\Analyzers\PayloadAnalyzerConfiguration
+ * @var \Nasqueron\Notifications\Analyzers\PayloadAnalyzerConfiguration
*/
protected $configuration;
diff --git a/tests/Notifications/DockerHubNotificationTest.php b/tests/Notifications/DockerHubNotificationTest.php
--- a/tests/Notifications/DockerHubNotificationTest.php
+++ b/tests/Notifications/DockerHubNotificationTest.php
@@ -14,7 +14,7 @@
use WithMockHttpClient;
/**
- * @return Nasqueron\Notifications\Notifications\DockerHubNotification
+ * @return \Nasqueron\Notifications\Notifications\DockerHubNotification
*/
protected function prepareNotification ($event) {
$path = __DIR__ . '/../data/payloads/DockerHub' . ucfirst($event)
@@ -71,7 +71,7 @@
}
/**
- * @return stdClass
+ * @return \stdClass
*/
protected function mockMailgunResponse () {
return json_decode($this->mockHttpClientResponseBody());
diff --git a/tests/Notifications/JenkinsNotificationTest.php b/tests/Notifications/JenkinsNotificationTest.php
--- a/tests/Notifications/JenkinsNotificationTest.php
+++ b/tests/Notifications/JenkinsNotificationTest.php
@@ -7,12 +7,12 @@
class JenkinsNotificationTest extends TestCase {
/**
- * @var Nasqueron\Notifications\Notifications\JenkinsNotification
+ * @var \Nasqueron\Notifications\Notifications\JenkinsNotification
*/
private $notification;
/**
- * @var stdClass
+ * @var \stdClass
*/
private $payload;
diff --git a/tests/Phabricator/ProjectsMapTest.php b/tests/Phabricator/ProjectsMapTest.php
--- a/tests/Phabricator/ProjectsMapTest.php
+++ b/tests/Phabricator/ProjectsMapTest.php
@@ -11,7 +11,7 @@
class ProjectsMapTest extends TestCase {
/**
- * @var Nasqueron\Notifications\Phabricator\ProjectsMap
+ * @var \Nasqueron\Notifications\Phabricator\ProjectsMap
*/
private $map;
diff --git a/tests/Services/ServiceTest.php b/tests/Services/ServiceTest.php
--- a/tests/Services/ServiceTest.php
+++ b/tests/Services/ServiceTest.php
@@ -8,12 +8,12 @@
class ServiceTest extends TestCase {
/**
- * @var Nasqueron\Notifications\Services\Service
+ * @var \Nasqueron\Notifications\Services\Service
*/
private $serviceWithInstance;
/**
- * @var Nasqueron\Notifications\Services\Service
+ * @var \Nasqueron\Notifications\Services\Service
*/
private $serviceWithoutInstance;
diff --git a/tests/TestCase.php b/tests/TestCase.php
--- a/tests/TestCase.php
+++ b/tests/TestCase.php
@@ -73,7 +73,7 @@
/**
* Mocks the Phabricator API
*
- * @return Nasqueron\Notifications\Phabricator\PhabricatorAPIFactory The mock
+ * @return \Nasqueron\Notifications\Phabricator\PhabricatorAPIFactory The mock
*/
protected function mockPhabricatorAPI () {
// Inject into our container a mock of PhabricatorAPI

File Metadata

Mime Type
text/plain
Expires
Sat, Apr 19, 21:48 (9 h, 7 m)
Storage Engine
blob
Storage Format
Raw Data
Storage Handle
2586209
Default Alt Text
D769.diff (29 KB)

Event Timeline
diff --git a/app/Phabricator/PhabricatorStory.php b/app/Phabricator/PhabricatorStory.php
--- a/app/Phabricator/PhabricatorStory.php
+++ b/app/Phabricator/PhabricatorStory.php
@@ -81,15 +81,15 @@
}
/**
* Initializes a new instance of PhabricatorStory from an array.
*
* This is intended to parse the feed.hooks payloads.
*
* @param string $instanceName The Phabricator instance name
* @param string $payload The data submitted by Phabricator
* @return PhabricatorStory
*/
- public static function loadFromArray ($instanceName, $payload) {
+ public static function loadFromIterable (string $instanceName, iterable $payload) {
$instance = new self($instanceName);
foreach ($payload as $key => $value) {
@@ -116,7 +116,7 @@
throw new InvalidArgumentException("Payload should be deserializable as an array.");
}
- return self::loadFromArray($instanceName, $array);
+ return self::loadFromIterable($instanceName, $array);
}
///
@@ -81,15 +81,15 @@
}
/**
- * Initializes a new instance of PhabricatorStory from an array.
+ * Initializes a new instance of PhabricatorStory from an iterable.
*
* This is intended to parse the feed.hooks payloads.
@@ -81,15 +81,15 @@
*
* @param string $instanceName The Phabricator instance name
- * @param string $payload The data submitted by Phabricator
+ * @param iterable $payload The data submitted by Phabricator
* @return PhabricatorStory
*/